@@ -1,5 +1,5 @@
 #    __init__.py -- The plugin for bzr
-#    Copyright (C) 2005 Jamie Wilkinson <jaq@debian.org> 
+#    Copyright (C) 2005 Jamie Wilkinson <jaq@debian.org>
 #                  2006, 2007 James Westby <jw+debian@jameswestby.net>
 #                  2007 Reinhard Tartler <siretart@tauware.de>
 #                  2008 Canonical Ltd.
@@ -25,31 +25,38 @@
 
 import os
 
-import breezy
+import breezy  # noqa: F401
 from ...commands import plugin_cmds
 from ...hooks import install_lazy_named_hook
 from ... import trace
 
-from .info import (
+from .info import (  # noqa: F401
     brz_plugin_version as version_info,
+)
+
+from ...directory_service import (
+    AliasDirectory,
+    directories,
     )
 
-
 from ...i18n import load_plugin_translations
+from ...tag import tag_sort_methods
+from ...revisionspec import revspec_registry
+
 translation = load_plugin_translations("brz-debian")
 gettext = translation.gettext
 
 
 commands = {
-        "builddeb_do": ["bd-do"],
-        "builddeb": ["bd", "debuild"],
-        "get_orig_source": [],
-        "dep3_patch": [],
-        "import_dsc": [],
-        "import_upstream": [],
-        "merge_upstream": ["mu"],
-        "debrelease": [],
-        }
+    "builddeb_do": ["bd-do"],
+    "builddeb": ["bd", "debuild"],
+    "get_orig_source": [],
+    "dep3_patch": [],
+    "import_dsc": [],
+    "import_upstream": [],
+    "merge_upstream": ["mu"],
+    "debrelease": [],
+}
 
 for command, aliases in commands.items():
     plugin_cmds.register_lazy(
@@ -66,64 +73,32 @@ default_orig_dir = '..'
 default_result_dir = '..'
 
 
-try:
-    from ...registry import register_lazy
-except ImportError:
-    from ...directory_service import (
-        AliasDirectory,
-        directories,
-        )
+directories.register_lazy(
+    "apt:", __name__ + '.directory',
+    'AptDirectory',
+    "Directory that uses Vcs-* control fields in apt to look up branches")
+directories.register_lazy(
+    "dgit:", __name__ + '.directory',
+    'DgitDirectory',
+    "Directory that uses Debian Dgit control fields to look up branches")
+directories.register_lazy(
+    "vcs:", __name__ + '.directory',
+    'VcsDirectory',
+    "Directory that uses local Debian Vcs-* control fields to look up "
+    "branches")
 
-    directories.register_lazy(
-        "apt:", __name__ + '.directory',
-        'AptDirectory',
-        "Directory that uses Vcs-* control fields in apt to look up branches")
-    directories.register_lazy(
-        "dgit:", __name__ + '.directory',
-        'DgitDirectory',
-        "Directory that uses Debian Dgit control fields to look up branches")
-    directories.register_lazy(
-        "vcs:", __name__ + '.directory',
-        'VcsDirectory',
-        "Directory that uses local Debian Vcs-* control fields to look up "
-        "branches")
+AliasDirectory.branch_aliases.register_lazy(
+    "upstream", __name__ + ".directory", "upstream_branch_alias",
+    help="upstream branch (for packaging branches)")
 
-    branch_aliases = getattr(AliasDirectory, "branch_aliases", None)
-    if branch_aliases is not None:
-        branch_aliases.register_lazy(
-            "upstream", __name__ + ".directory", "upstream_branch_alias",
-            help="upstream branch (for packaging branches)")
+tag_sort_methods.register_lazy(
+    "debversion", __name__ + ".tagging", "sort_debversion",
+    "Sort like Debian versions.")
 
-    from ...tag import tag_sort_methods
-    tag_sort_methods.register_lazy(
-        "debversion", __name__ + ".tagging", "sort_debversion",
-        "Sort like Debian versions.")
-
-    from ...revisionspec import revspec_registry
-    revspec_registry.register_lazy(
-        "package:", __name__ + ".revspec", "RevisionSpec_package")
-    revspec_registry.register_lazy(
-        "upstream:", __name__ + ".revspec", "RevisionSpec_upstream")
-else:
-    register_lazy(
-        "breezy.directory", "directories", "apt:",
-        __name__ + '.directory', 'VcsDirectory',
-        help="Directory that uses Debian Vcs-* control "
-             "fields to look up branches")
-    register_lazy(
-        "breezy.directory", "AliasDirectory.branch_aliases", "upstream",
-        __name__ + ".directory", "upstream_branch_alias",
-        help="upstream branch (for packaging branches)")
-    register_lazy(
-        "breezy.tag", "tag_sort_methods", "debversion",
-        __name__ + ".tagging", "sort_debversion",
-        "Sort like Debian versions.")
-    register_lazy(
-        "breezy.revisionspec", "revspec_registry", "package:",
-        __name__ + ".revspec", "RevisionSpec_package")
-    register_lazy(
-        "breezy.revisionspec", "revspec_registry", "upstream:",
-        __name__ + ".revspec", "RevisionSpec_upstream")
+revspec_registry.register_lazy(
+    "package:", __name__ + ".revspec", "RevisionSpec_package")
+revspec_registry.register_lazy(
+    "upstream:", __name__ + ".revspec", "RevisionSpec_upstream")
 
 
 def debian_changelog_commit_message(commit, start_message):
