@@ -24,10 +24,12 @@ from ...config import (
   configobj,
   ConfigObj,
   TreeConfig,
-  )
-from ...errors import BzrError, NoSuchFile
+)
+from ...errors import BzrError
 from ...trace import mutter, warning
 
+from breezy.transport import NoSuchFile
+
 
 BUILD_TYPE_NORMAL = "normal"
 BUILD_TYPE_NATIVE = "native"
@@ -35,7 +37,7 @@ BUILD_TYPE_MERGE = "merge"
 BUILD_TYPE_SPLIT = "split"
 
 
-class SvnBuildPackageMappedConfig(object):
+class SvnBuildPackageMappedConfig:
     """Config object that provides a bzr-builddeb configuration
     based on a svn-buildpackage configuration.
     """
@@ -66,7 +68,7 @@ class UpstreamMetadataSyntaxError(BzrError):
         self.error = error
 
 
-class UpstreamMetadataConfig(object):
+class UpstreamMetadataConfig:
     """Config object that represents debian/upstream/metadata.
     """
 
@@ -76,15 +78,19 @@ class UpstreamMetadataConfig(object):
         try:
             self.metadata = yaml.safe_load(text)
         except yaml.composer.ComposerError as e:
-            all_metadata = [x for x in yaml.safe_load_all(text) if x is not None]
+            all_metadata = [
+                x for x in yaml.safe_load_all(text) if x is not None]
             if len(all_metadata) != 1:
                 raise UpstreamMetadataSyntaxError(
-                    'debian/upstream/metadata', Exception('multiple documents found'))
-            warning('ignoring empty extra documents in debian/upstream/metadata')
+                    'debian/upstream/metadata',
+                    Exception('multiple documents found')) from e
+            warning(
+                'ignoring empty extra documents in debian/upstream/metadata')
             self.metadata = all_metadata[0]
         except (yaml.scanner.ScannerError, yaml.composer.ComposerError,
                 yaml.parser.ParserError) as e:
-            raise UpstreamMetadataSyntaxError('debian/upstream/metadata', e)
+            raise UpstreamMetadataSyntaxError(
+                'debian/upstream/metadata', e) from e
         if isinstance(self.metadata, str):
             raise UpstreamMetadataSyntaxError(
               'debian/upstream/metadata', TypeError(self.metadata))
@@ -112,7 +118,7 @@ class UpstreamMetadataConfig(object):
         raise KeyError
 
 
-class DebBuildConfig(object):
+class DebBuildConfig:
     """Holds the configuration settings for builddeb. These are taken from
     a hierarchy of config files. .bzr-builddeb/local.conf then
     debian/bzr-builddeb.conf.local,
@@ -201,8 +207,13 @@ class DebBuildConfig(object):
             except NoSuchFile:
                 pass
             else:
-                self._config_files.append(
-                    (UpstreamMetadataConfig(upstream_metadata_text), False))
+                try:
+                    self._config_files.append(
+                        (UpstreamMetadataConfig(upstream_metadata_text),
+                         False))
+                except UpstreamMetadataSyntaxError as e:
+                    warning(
+                        'Ignoring upstream metadata due to %s', e)
         self.user_config = None
 
     def set_user_config(self, user_conf):
