@@ -18,11 +18,24 @@
 
 brz_plugin_name = 'debian'
 
-brz_plugin_version = (2, 8, 51, 'final', 0)
+brz_plugin_version = (2, 8, 72, 'final', 0)
 
 brz_commands = [
     "builddeb",
     "merge_upstream",
     "import_dsc",
     "bd_do",
-    ]
+]
+
+
+def versions_dict():
+    import breezy
+    import debian
+    import debmutate
+    return {
+        'python-debian': debian.__version__,
+        'debmutate': debmutate.version_string,
+        'breezy': breezy.version_string,
+        'breezy-debian': ".".join(
+            [str(v) for v in brz_plugin_version[:3]]),
+    }
