@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # Copyright ? 2008 Canonical Ltd.
 # Author: Scott James Remnant <scott@ubuntu.com>.
 # Hacked up by: Bryce Harrington <bryce@ubuntu.com>
@@ -32,7 +31,7 @@ from ... import (
 # A logger in the 'bzr' hierarchy.  By default messages will be propagated to
 # the standard bzr logger, but tests can easily intercept just this logger if
 # they wish.
-_logger = logging.getLogger('breezy.plugins.debian.merge_changelog')
+_logger = logging.getLogger(__name__)
 
 
 class ChangeLogFileMerge(merge.ConfigurableFileMerger):
