@@ -21,9 +21,7 @@ import os
 
 from debian.changelog import Version
 
-from ....errors import (
-    FileExists,
-    )
+from ....transport import FileExists
 
 from ..upstream import MissingUpstreamTarball
 from ..source_distiller import (
@@ -179,10 +177,11 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         version = Version("0.1-1")
         self.make_tarball(name, version)
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/foo')
         self.assertPathExists(
-            'target/%s_%s.orig.tar.gz' % (name, version.upstream_version))
+            'target/{}_{}.orig.tar.gz'.format(name, version.upstream_version))
         self.assertPathExists('target/foo/a')
 
     def test_distill_exports_branch(self):
@@ -195,7 +194,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         version = Version("0.1-1")
         self.make_tarball(name, version)
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/')
         self.assertPathExists('target/debian/a')
         self.assertPathDoesNotExist('target/.bzr-builddeb')
@@ -214,7 +214,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         builder.add_default_control()
         builder.build()
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/')
         self.assertPathExists('target/a')
         self.assertPathDoesNotExist('target/debian/foo')
@@ -229,7 +230,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         version = Version("0.1-1")
         self.make_tarball(name, version)
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."),
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."),
             top_level=True)
         sd.distill('target/')
         self.assertPathExists('target/a')
@@ -248,7 +250,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         version = Version("0.1-1")
         self.make_tarball(name, version)
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."),
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."),
             use_existing=True)
         self.build_tree(
             ['target/', 'target/b', 'target/debian/', 'target/debian/b'])
@@ -269,7 +272,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         version = Version("0.1-1")
         self.make_tarball(name, version)
         sd = MergeModeDistiller(
-            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
+            wt, '',
+            _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/debian/a')
