@@ -30,6 +30,6 @@ class TestDebVersionSort(TestCase):
     def test_sort(self):
         tags = [("1.0", "revid"), ("1.0.1", "revid"), ("1.0~1", "revid")]
         tagging.sort_debversion(None, tags)
-        self.assertEquals(
+        self.assertEqual(
             tags,
             [("1.0~1", "revid"), ("1.0", "revid"), ("1.0.1", "revid")])
