@@ -336,18 +336,25 @@ class BasePristineTarSource(UpstreamSource):
                 package, version, component, md5)
         return ret
 
-    def has_version(
+    def version_tag(
             self, package: Optional[str], version: str, tarballs=None,
-            try_hard=True):
+            try_hard=True) -> str | None:
         if tarballs is None:
             return self.has_version_component(
                 package, version, component=None, try_hard=try_hard)
         else:
+            tag = None
             for (tarball, component, md5) in tarballs:
-                if not self.has_version_component(
-                        package, version, component, md5, try_hard=try_hard):
-                    return False
-            return True
+                tag = self.has_version_component(
+                        package, version, component, md5, try_hard=try_hard)
+                if tag is None:
+                    return None
+            return tag
+
+    def has_version(
+            self, package: Optional[str], version: str, tarballs=None,
+            try_hard=True) -> bool:
+        return self.version_tag(package, version, tarballs=tarballs, try_hard=try_hard) is not None
 
     def _components_by_version(self):
         ret = {}
@@ -401,7 +408,7 @@ class BasePristineTarSource(UpstreamSource):
 
     def has_version_component(
             self, package: Optional[str], version: str, component,
-            md5=None, try_hard=True):
+            md5=None, try_hard=True) -> str | None:
         for tag_name in self.possible_tag_names(
                 package, version, component=component, try_hard=try_hard):
             try:
@@ -410,8 +417,8 @@ class BasePristineTarSource(UpstreamSource):
                 continue
             else:
                 if self._has_revision(revid, md5=md5):
-                    return True
-        return False
+                    return tag_name
+        return None
 
 
 class BzrPristineTarSource(BasePristineTarSource):
